/**
 * 会员逻辑
 */

import { MEMBERSTATE, MEMBERLEVEL, DOCUMENTTYPE, NATION, PROFCATEGORY } from "../../config/enum";
import { ERRORENUM } from "../../config/errorEnum";
import { TABLEENUM } from "../../data/models/model";
import { find, findOnce } from "../../data/select";
import { updateOneData } from "../../data/update";
import { generateSystemId, successResult } from "../../tools/system";
import { BizError } from "../../util/bizError";
import { extractData } from "../../util/piecemeal";
import { changeEnumValue } from "../../util/verificationEnum";


/**
 * 单位会员列表
 * @param param0 
 */
export async function unitMemberList({unitName, joinTime, unitMemberType, workDuties, session, sheng, shi, qu}) {
    let selectParam:any = {};
    if (unitName) selectParam.unitName = unitName;
    if (joinTime) selectParam.joinTime = joinTime;
    if (unitMemberType) selectParam.unitMemberType = unitMemberType;
    if (workDuties) selectParam.workDuties = workDuties;
    if (session) selectParam.session = session;
    if (sheng) selectParam.sheng = sheng;
    if (shi) selectParam.shi = shi;
    if (qu) selectParam.qu = qu;

    let dbList = await find(TABLEENUM.用户表, selectParam);
    let dataList = [];
    dbList.forEach(info => {
        let item:any = extractData(info, ["userId", "memberState", "unitName", "loginId", "phone", "joinTime", "unitMemberLevel", "sheng", "shi", "qu"]);
        changeEnumValue(MEMBERSTATE, item.memberState);
        if (!item.memberLevel) item.memberLevel = "未选择";
        else changeEnumValue(MEMBERLEVEL, item.memberLevel);
        dataList.push(item);
    });

    return {dataList};
}


/**
 * 单位会员详情
 * @param param0 
 * @returns {顶部数据, 基本信息, 单位信息, 单位所获得科研成果}
 */

const UnitBasicConfig = ["userId", "unitName", "addres", "officialWebsite", "uscc", "legalPerson", "legalPersonPhone", "gongZhongHao", 
"unitPhone", "contactPerson", "contactPersonDuties", "sheng", "shi", "qu", "uusinessLicenseUrl", "personInChargeDesc"];
const UnitConfig = ["unitInfoType", "yuanXiaoBanXueLeiXing", "yuanXiaoZhuGuanBuMen", "yuanXiaoFuZeRen", "yuanXiaoFuZeRenZhiWu", 
"yuanXiaoFuZeRenDianHua", "yuanXiaoBanGongFuZeRen", "yuanXiaoBanGongFuZeRenZhiWu", "yuanXiaoBanGongFuZeRenDianHua", "yuanXiaoKeYanFuZeRen", 
"yuanXiaoKeYanFuZeRenZhiWu", "yuanXiaoKeYanFuZeRenDianHua", "yuanXiaoXueShengZongRenShu", "yuanXiaoJiaoZhiGongZongRenShu", "yuanXiaoJianZhuMianJi", 
"yuanXiaoGaoJiZhiCheng", "yuanXiaoKaiSheZhuanYe"];

export async function unitMemberDetails({userId}) {
    let oldInfo = await findOnce(TABLEENUM.用户表, {userId});
    if (!oldInfo || !oldInfo.userId) throw new BizError(ERRORENUM.目标数据不存在);
    let topInfo:any = extractData(oldInfo, ["session", "memberLevel"]);
    changeEnumValue(MEMBERLEVEL, topInfo.memberLevel);
    let basicInfo = extractData(oldInfo, UnitBasicConfig);
    let unitInfo = extractData(oldInfo, UnitConfig);
    
    let oldKeYanInfo = await findOnce(TABLEENUM.单位所获得科研成果表, {userId});
    let scientificResearch = extractData(oldKeYanInfo, ["startTime", "endTime", "describe"]);
    
    return {topInfo, basicInfo, unitInfo, scientificResearch};
}



/**
 * 单位会员 修改
 * @param userId
 * @param form
 * @returns 
 */
export async function unitMemberUpdate(secureArgs:any) {
    let {userId, form, keyanForm} = secureArgs;
    let oldInfo = await findOnce(TABLEENUM.用户表, {userId});
    if (!oldInfo || !oldInfo.userId) throw new BizError(ERRORENUM.目标数据不存在);

    await updateOneData(TABLEENUM.用户表, {userId}, form);
    return successResult();
}



















/**
 * 个人会员列表
 * @param param0 
 */
export async function individualMemberList({name, documentId, phone, memberLevel, workDuties, session, joinTime, auditTime, memberState}) {
    let selectParam:any = {};
    if (name) selectParam.name = name;
    if (documentId) selectParam.documentId = documentId;
    if (phone) selectParam.phone = phone;
    if (memberLevel) selectParam.memberLevel = memberLevel;
    if (workDuties) selectParam.workDuties = workDuties;
    if (session) selectParam.session = session;
    if (joinTime) selectParam.joinTime = joinTime;
    if (auditTime) selectParam.auditTime = auditTime;
    if (memberState) selectParam.memberState = memberState;

    let dbList = await find(TABLEENUM.用户表, selectParam);
    let dataList = [];
    dbList.forEach(info => {
        let item:any = extractData(info, ["userId", "memberState", "unitName", "name", "sex", "nation", "loginId", "phone", "joinTime", "memberLevel", "sheng", "shi", "qu"]);
        changeEnumValue(MEMBERSTATE, item.memberState);
        if (!item.memberLevel) item.memberLevel = "未选择";
        else changeEnumValue(MEMBERLEVEL, item.memberLevel);
        dataList.push(item);
    });

    return {dataList};
}


/**
 * 个人会员详情
 * @param param0 
 * @returns {顶部数据, 基本信息, 专业信息, 其他附件}
 */

const IndividualBasicConfig = ["name", "sex", "nation", "birth", "documentType", "documentId", "sheng", "shi", "qu", "addres", "photoUrl"];
const SpecialityConfig = ["unitName", "workDuties", "workTitle", "profCategory", "studyResume", "workResume", "profAchievement", "otherEMP", "otherPROF"];

export async function individualMemberDetails({userId}) {
    let oldInfo = await findOnce(TABLEENUM.用户表, {userId});
    if (!oldInfo || !oldInfo.userId) throw new BizError(ERRORENUM.目标数据不存在);

    let topInfo:any = extractData(oldInfo, ["session", "memberLevel"]);
    changeEnumValue(MEMBERLEVEL, topInfo.memberLevel);

    let basicInfo:any = extractData(oldInfo, IndividualBasicConfig);
    changeEnumValue(DOCUMENTTYPE, basicInfo.documentType);
    changeEnumValue(NATION, basicInfo.nation);

    let specialityInfo:any = extractData(oldInfo, SpecialityConfig);
    changeEnumValue(PROFCATEGORY, basicInfo.profCategory);
    
    let otherAttachment:any = extractData(oldInfo, ["cardUrl", "academicCERTUrl", "professionalCERTUrl", "auxiliaryMaterial"]);
    
    return {topInfo, basicInfo, specialityInfo, otherAttachment};
}









